//
//  IconStyleManager.h
//  Add Folder Icons
//
//  Created by Andrew Hodgkinson on 24/01/2011.
//  Copyright 2011 Hipposoft. All rights reserved.
//
//  Always use "+iconStyleManager" to obtain references to instances of this
//  class.
//

#import <Cocoa/Cocoa.h>
#import "IconStyle.h"
#import "CoreDataObjectIDTransformer.h"
#import "SCEventListenerProtocol.h"
#import "SCEvents.h"

#define CORE_DATA_STORE_FILENAME             @"Icon Styles.xml"
#define CORE_DATA_OBJECT_ID_TRANSFORMER_NAME @"CoreDataObjectIDTransformer"
#define DEFAULT_ICON_STYLE_NAME              NSLocalizedString( @"Preset: Classic thumbnails", @"Name of 'classic' preset icon style" )

#define PREFERENCES_DEFAULT_STYLE_KEY        @"defaultStyle"

@interface IconStyleManager : NSObject < SCEventListenerProtocol,
                                         NSAlertDelegate >
{
    /* Boilerplate Core Data material generated by Interface Builder 3.2.5 */

    NSPersistentStoreCoordinator * persistentStoreCoordinator;
    NSManagedObjectModel         * managedObjectModel;
    NSManagedObjectContext       * managedObjectContext;

    /* Boilerplate ends */

    CoreDataObjectIDTransformer  * coreDataObjectIDTransformer;
    NSMutableArray               * slipCoverDefinitions;
    SCEvents                     * slipCoverCaseFolderWatcher;
}

/* Boilerplate Core Data material generated by Interface Builder 3.2.5 */

@property ( nonatomic, retain, readonly ) NSPersistentStoreCoordinator * persistentStoreCoordinator;
@property ( nonatomic, retain, readonly ) NSManagedObjectModel         * managedObjectModel;
@property ( nonatomic, retain, readonly ) NSManagedObjectContext       * managedObjectContext;

/* Boilerplate ends */

/* Other properties */

@property ( retain, readonly ) NSMutableArray * slipCoverDefinitions;

/* Allocation and initialisation */

+ ( IconStyleManager * ) iconStyleManager;

/* General methods */

- ( void        ) establishPresetIconStyles;
- ( NSArray   * ) findSlipCoverStyles;
- ( void        ) checkIconStylesForValidity;
- ( IconStyle * ) findDefaultIconStyle;
- ( IconStyle * ) findClassicIconStyle;

- ( IconStyle * ) insertBlankUserStyleAndProcessChanges;

/* Implement SCEventListenerProtocol */

- ( void ) pathWatcher: ( SCEvents * ) pathWatcher eventOccurred: ( SCEvent * ) event;

/* Implement NSAlertDelegate */

- ( BOOL ) alertShowHelp: ( NSAlert * ) alert;

@end
